==> mit-scheme_9.1.1.orig.tar.gz: mit-scheme-9.1.1/src/microcode/ospty.h <==
/* -*-C-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010, 2011 Massachusetts Institute of
    Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

*/

#ifndef SCM_OSPTY_H
#define SCM_OSPTY_H

#include "os.h"

extern const char * OS_open_pty_master
  (Tchannel * master_fd, const char ** master_fname);
extern void OS_pty_master_send_signal (Tchannel channel, int sig);
extern void OS_pty_master_kill (Tchannel channel);
extern void OS_pty_master_stop (Tchannel channel);
extern void OS_pty_master_continue (Tchannel channel);
extern void OS_pty_master_interrupt (Tchannel channel);
extern void OS_pty_master_quit (Tchannel channel);
extern void OS_pty_master_hangup (Tchannel channel);

#endif /* SCM_OSPTY_H */

==> mit-scheme-9.2.tar.gz: mit-scheme-9.2/src/microcode/ospty.h <==
/* -*-C-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Massachusetts
    Institute of Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

*/

#ifndef SCM_OSPTY_H
#define SCM_OSPTY_H

#include "os.h"

extern const char * OS_open_pty_master
  (Tchannel * master_fd, const char ** master_fname);
extern void OS_pty_master_send_signal (Tchannel channel, int sig);
extern void OS_pty_master_kill (Tchannel channel);
extern void OS_pty_master_stop (Tchannel channel);
extern void OS_pty_master_continue (Tchannel channel);
extern void OS_pty_master_interrupt (Tchannel channel);
extern void OS_pty_master_quit (Tchannel channel);
extern void OS_pty_master_hangup (Tchannel channel);

#endif /* SCM_OSPTY_H */
